==> openshift-model-miscellaneous-5.10.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/BareMetalHostSpecBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class BareMetalHostSpecBuilder extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpecFluentImpl<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpec,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpecBuilder>{
  public BareMetalHostSpecBuilder() {
    this(false);
  }
  public BareMetalHostSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new BareMetalHostSpec(), validationEnabled);
  }
  public BareMetalHostSpecBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public BareMetalHostSpecBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new BareMetalHostSpec(), validationEnabled);
  }
  public BareMetalHostSpecBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpecFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpec instance) {
    this(fluent, instance, false);
  }
  public BareMetalHostSpecBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpecFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAutomatedCleaningMode(instance.getAutomatedCleaningMode()); 
    fluent.withBmc(instance.getBmc()); 
    fluent.withBootMACAddress(instance.getBootMACAddress()); 
    fluent.withBootMode(instance.getBootMode()); 
    fluent.withConsumerRef(instance.getConsumerRef()); 
    fluent.withDescription(instance.getDescription()); 
    fluent.withExternallyProvisioned(instance.getExternallyProvisioned()); 
    fluent.withFirmware(instance.getFirmware()); 
    fluent.withHardwareProfile(instance.getHardwareProfile()); 
    fluent.withImage(instance.getImage()); 
    fluent.withMetaData(instance.getMetaData()); 
    fluent.withNetworkData(instance.getNetworkData()); 
    fluent.withOnline(instance.getOnline()); 
    fluent.withRaid(instance.getRaid()); 
    fluent.withRootDeviceHints(instance.getRootDeviceHints()); 
    fluent.withTaints(instance.getTaints()); 
    fluent.withUserData(instance.getUserData()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public BareMetalHostSpecBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpec instance) {
    this(instance,false);
  }
  public BareMetalHostSpecBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAutomatedCleaningMode(instance.getAutomatedCleaningMode()); 
    this.withBmc(instance.getBmc()); 
    this.withBootMACAddress(instance.getBootMACAddress()); 
    this.withBootMode(instance.getBootMode()); 
    this.withConsumerRef(instance.getConsumerRef()); 
    this.withDescription(instance.getDescription()); 
    this.withExternallyProvisioned(instance.getExternallyProvisioned()); 
    this.withFirmware(instance.getFirmware()); 
    this.withHardwareProfile(instance.getHardwareProfile()); 
    this.withImage(instance.getImage()); 
    this.withMetaData(instance.getMetaData()); 
    this.withNetworkData(instance.getNetworkData()); 
    this.withOnline(instance.getOnline()); 
    this.withRaid(instance.getRaid()); 
    this.withRootDeviceHints(instance.getRootDeviceHints()); 
    this.withTaints(instance.getTaints()); 
    this.withUserData(instance.getUserData()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpec build() {
    BareMetalHostSpec buildable = new BareMetalHostSpec(fluent.getAutomatedCleaningMode(),fluent.getBmc(),fluent.getBootMACAddress(),fluent.getBootMode(),fluent.getConsumerRef(),fluent.getDescription(),fluent.getExternallyProvisioned(),fluent.getFirmware(),fluent.getHardwareProfile(),fluent.getImage(),fluent.getMetaData(),fluent.getNetworkData(),fluent.getOnline(),fluent.getRaid(),fluent.getRootDeviceHints(),fluent.getTaints(),fluent.getUserData());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BareMetalHostSpecBuilder that = (BareMetalHostSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-5.12.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/BareMetalHostSpecBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class BareMetalHostSpecBuilder extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpecFluentImpl<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpec,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpecBuilder>{
  public BareMetalHostSpecBuilder() {
    this(false);
  }
  public BareMetalHostSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new BareMetalHostSpec(), validationEnabled);
  }
  public BareMetalHostSpecBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public BareMetalHostSpecBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new BareMetalHostSpec(), validationEnabled);
  }
  public BareMetalHostSpecBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpecFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpec instance) {
    this(fluent, instance, false);
  }
  public BareMetalHostSpecBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpecFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAutomatedCleaningMode(instance.getAutomatedCleaningMode()); 
    fluent.withBmc(instance.getBmc()); 
    fluent.withBootMACAddress(instance.getBootMACAddress()); 
    fluent.withBootMode(instance.getBootMode()); 
    fluent.withConsumerRef(instance.getConsumerRef()); 
    fluent.withCustomDeploy(instance.getCustomDeploy()); 
    fluent.withDescription(instance.getDescription()); 
    fluent.withExternallyProvisioned(instance.getExternallyProvisioned()); 
    fluent.withFirmware(instance.getFirmware()); 
    fluent.withHardwareProfile(instance.getHardwareProfile()); 
    fluent.withImage(instance.getImage()); 
    fluent.withMetaData(instance.getMetaData()); 
    fluent.withNetworkData(instance.getNetworkData()); 
    fluent.withOnline(instance.getOnline()); 
    fluent.withPreprovisioningNetworkDataName(instance.getPreprovisioningNetworkDataName()); 
    fluent.withRaid(instance.getRaid()); 
    fluent.withRootDeviceHints(instance.getRootDeviceHints()); 
    fluent.withTaints(instance.getTaints()); 
    fluent.withUserData(instance.getUserData()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public BareMetalHostSpecBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpec instance) {
    this(instance,false);
  }
  public BareMetalHostSpecBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAutomatedCleaningMode(instance.getAutomatedCleaningMode()); 
    this.withBmc(instance.getBmc()); 
    this.withBootMACAddress(instance.getBootMACAddress()); 
    this.withBootMode(instance.getBootMode()); 
    this.withConsumerRef(instance.getConsumerRef()); 
    this.withCustomDeploy(instance.getCustomDeploy()); 
    this.withDescription(instance.getDescription()); 
    this.withExternallyProvisioned(instance.getExternallyProvisioned()); 
    this.withFirmware(instance.getFirmware()); 
    this.withHardwareProfile(instance.getHardwareProfile()); 
    this.withImage(instance.getImage()); 
    this.withMetaData(instance.getMetaData()); 
    this.withNetworkData(instance.getNetworkData()); 
    this.withOnline(instance.getOnline()); 
    this.withPreprovisioningNetworkDataName(instance.getPreprovisioningNetworkDataName()); 
    this.withRaid(instance.getRaid()); 
    this.withRootDeviceHints(instance.getRootDeviceHints()); 
    this.withTaints(instance.getTaints()); 
    this.withUserData(instance.getUserData()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.BareMetalHostSpec build() {
    BareMetalHostSpec buildable = new BareMetalHostSpec(fluent.getAutomatedCleaningMode(),fluent.getBmc(),fluent.getBootMACAddress(),fluent.getBootMode(),fluent.getConsumerRef(),fluent.getCustomDeploy(),fluent.getDescription(),fluent.getExternallyProvisioned(),fluent.getFirmware(),fluent.getHardwareProfile(),fluent.getImage(),fluent.getMetaData(),fluent.getNetworkData(),fluent.getOnline(),fluent.getPreprovisioningNetworkDataName(),fluent.getRaid(),fluent.getRootDeviceHints(),fluent.getTaints(),fluent.getUserData());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BareMetalHostSpecBuilder that = (BareMetalHostSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
